/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.client.collector;

import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.appspy.client.common.CollectorFactory;
import org.appspy.client.common.CollectorInfo;
import org.appspy.core.data.CollectedData;
import org.appspy.server.service.DataCollectionService;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class SimpleDataSender implements DataSender {
	
	protected static Log sLog = LogFactory.getLog(SimpleDataSender.class);
	
	protected List<DataCollectionService> mDataCollectionServices = null;

	/* (non-Javadoc)
	 * @see org.appspy.core.client.collector.DataSender#sendData(java.util.List)
	 */
	public void sendData(List<CollectedData> collectedDatas) {
		
		for (DataCollectionService collectionService : mDataCollectionServices) {
			try
			{
				collectionService.collectData(collectedDatas);
				if (CollectorFactory.getCollectorInfo().getStatus() != CollectorInfo.STATUS_STOPPED)
				{
					CollectorFactory.getCollectorInfo().setStatus(CollectorInfo.STATUS_RUNNING, null);
				}
			}
			catch (Throwable t)
			{
				sLog.error("Error when sending collected data", t);
				if (CollectorFactory.getCollectorInfo().getStatus() != CollectorInfo.STATUS_STOPPED)
				{
					CollectorFactory.getCollectorInfo().setStatus(CollectorInfo.STATUS_ERROR, t);
				}
			}
		}
		
	}

	/**
	 * @return the dataCollectionService
	 */
	public List<DataCollectionService> getDataCollectionServices() {
		return mDataCollectionServices;
	}

	/**
	 * @param dataCollectionService the dataCollectionService to set
	 */
	public void setDataCollectionServices(List<DataCollectionService> dataCollectionServices) {
		mDataCollectionServices = dataCollectionServices;
	}

	/* (non-Javadoc)
	 * @see org.appspy.core.client.collector.DataSender#destroy()
	 */
	public void destroy() {
	}

	/* (non-Javadoc)
	 * @see org.appspy.core.client.collector.DataSender#init()
	 */
	public void init() {
	}
	
	

}
